@@ -133,18 +133,18 @@ void ConfigLoaderHandler::endElement(const QStringView localName)
         resetState();
     } else if (caseInsensitiveCompare(localName, QLatin1String("label"))) {
         if (m_inChoice) {
-            m_choice.label = m_cdata.trimmed();
+            m_choice.label = std::move(m_cdata).trimmed();
         } else {
-            m_label = m_cdata.trimmed();
+            m_label = std::move(m_cdata).trimmed();
         }
     } else if (caseInsensitiveCompare(localName, QLatin1String("whatsthis"))) {
         if (m_inChoice) {
-            m_choice.whatsThis = m_cdata.trimmed();
+            m_choice.whatsThis = std::move(m_cdata).trimmed();
         } else {
-            m_whatsThis = m_cdata.trimmed();
+            m_whatsThis = std::move(m_cdata).trimmed();
         }
     } else if (caseInsensitiveCompare(localName, QLatin1String("default"))) {
-        m_default = m_cdata.trimmed();
+        m_default = std::move(m_cdata).trimmed();
     } else if (caseInsensitiveCompare(localName, QLatin1String("min"))) {
         m_min = m_cdata.toInt(&m_haveMin);
     } else if (caseInsensitiveCompare(localName, QLatin1String("max"))) {
@@ -244,8 +244,8 @@ void ConfigLoaderHandler::addItem()
         item = doubleItem;
     } else if (m_type == QLatin1String("intlist")) {
         QList<int> defaultList;
-        const QStringList tmpList = m_default.split(QLatin1Char(','), Qt::SkipEmptyParts);
-        for (const QString &tmp : tmpList) {
+        const QList<QStringView> tmpList = QStringView(m_default).split(QLatin1Char(','), Qt::SkipEmptyParts);
+        for (const QStringView tmp : tmpList) {
             defaultList.append(tmp.toInt());
         }
         item = m_config->addItemIntList(m_name, *d->newIntList(), defaultList, m_key);
@@ -265,7 +265,7 @@ void ConfigLoaderHandler::addItem()
         */
     } else if (m_type == QLatin1String("point")) {
         QPoint defaultPoint;
-        const QStringList tmpList = m_default.split(QLatin1Char(','));
+        const QList<QStringView> tmpList = QStringView(m_default).split(QLatin1Char(','));
         if (tmpList.size() >= 2) {
             defaultPoint.setX(tmpList[0].toInt());
             defaultPoint.setY(tmpList[1].toInt());
@@ -281,7 +281,7 @@ void ConfigLoaderHandler::addItem()
         item = m_config->addItemPointF(m_name, *d->newPointF(), defaultPointF, m_key);
     } else if (m_type == QLatin1String("rect")) {
         QRect defaultRect;
-        const QStringList tmpList = m_default.split(QLatin1Char(','));
+        const QList<QStringView> tmpList = QStringView(m_default).split(QLatin1Char(','));
         if (tmpList.size() >= 4) {
             defaultRect.setCoords(tmpList[0].toInt(), tmpList[1].toInt(), tmpList[2].toInt(), tmpList[3].toInt());
         }
@@ -295,7 +295,7 @@ void ConfigLoaderHandler::addItem()
         item = m_config->addItemRectF(m_name, *d->newRectF(), defaultRectF, m_key);
     } else if (m_type == QLatin1String("size")) {
         QSize defaultSize;
-        const QStringList tmpList = m_default.split(QLatin1Char(','));
+        const QList<QStringView> tmpList = QStringView(m_default).split(QLatin1Char(','));
         if (tmpList.size() >= 2) {
             defaultSize.setWidth(tmpList[0].toInt());
             defaultSize.setHeight(tmpList[1].toInt());
